@@ -15,11 +15,10 @@ from typing import Tuple
 from typing import TYPE_CHECKING
 from typing import Union
 
-from certbot_apache._internal import apache_util
-from certbot_apache._internal import constants
-
 from certbot import errors
 from certbot.compat import os
+from certbot_apache._internal import apache_util
+from certbot_apache._internal import constants
 
 if TYPE_CHECKING:
     from certbot_apache._internal.configurator import ApacheConfigurator  # pragma: no cover
@@ -154,7 +153,7 @@ class ApacheParser:
         try:
             # This is a noop save
             self.aug.save()
-        except (RuntimeError, IOError):
+        except (OSError, RuntimeError):
             self._log_save_errors(ex_errs)
             # Erase Save Notes
             self.configurator.save_notes = ""
@@ -199,7 +198,7 @@ class ApacheParser:
         ex_errs = self.aug.match("/augeas//error")
         try:
             self.aug.save()
-        except IOError:
+        except OSError:
             self._log_save_errors(ex_errs)
             raise
 
